Package 'multiDoE'

Title: Multi-Criteria Design of Experiments for Optimal Design
Description: Multi-criteria design of experiments algorithm that simultaneously optimizes up to six different criteria ('I', 'Id', 'D', 'Ds', 'A' and 'As'). The algorithm finds the optimal Pareto front and, if requested, selects a possible symmetrical design on it. The symmetrical design is selected based on two techniques: minimum distance with the Utopia point or the 'TOPSIS' approach.
Authors: Francesca Cucchi [aut], Andrea Melloncelli [aut, cre], Francesco Sambo [aut], Kalliopi Mylona [aut], Matteo Borrotti [aut]
Maintainer: Andrea Melloncelli <[email protected]>
License: CC BY 4.0
Version: 0.9.3
Built: 2026-06-09 08:51:50 UTC
Source: https://github.com/andreamelloncelli/multidoe

Help Index